@@ -1,7 +1,5 @@
-#!/usr/bin/env python3
-
 """
-copy and convert a cryosparc dir into a relion dir
+cs2star: Copy and convert a cryosparc dir into a relion dir
 """
 
 import sys
@@ -15,27 +13,52 @@ import click
 import pyem
 
 
-@click.command(context_settings=dict(help_option_names=['-h', '--help']))
+@click.command(context_settings=dict(help_option_names=['-h', '--help'], show_default=True))
 @click.argument('job_dir', type=click.Path(exists=True, file_okay=False, resolve_path=True))
 @click.argument('dest_dir', required=False, default='.', type=click.Path(file_okay=False))
 @click.option('-f', '--overwrite', count=True, help='overwrite the existing destination directory if present.'
               'Passed once, overwrite star file only. Twice, also files/symlinks')
 @click.option('-d', '--dry-run', is_flag=True)
-@click.option('-c/-s', '--copy/--symlink', help='copy the images or symlink to them [default: symlink]')
+@click.option('-c/-s', '--copy/--symlink', default=False, help='copy the images or symlink to them')
 @click.option('-m', '--micrographs', is_flag=True, help='copy/link the full micrographs')
-@click.option('-p', '--patches', is_flag=True, help='copy/link the particle patches, if available', show_default=True)
-@click.option('-r', '--relion-base-dir', type=click.Path(file_okay=False, resolve_path=True), help='base directory from which '
-                    'relion will be run. Useful if different from DEST_DIR, otherwise the paths in the .star file will be broken. '
-                    '[default: same as DEST_DIR]')
+@click.option('-p', '--patches', is_flag=True, help='copy/link the particle patches, if available')
 @click.option('--sets', help='only use these sets (only used if job is Particle Sets Tool). Comma-separated list.')
 @click.option('--classes', help='only use particles from these classes. Comma-separated list.')
-def main(job_dir, dest_dir, overwrite, dry_run, copy, micrographs, patches, relion_base_dir, sets, classes):
+@click.option('--swapxy/--no-swapxy', default=True, help='swap x and y axes')
+@click.option('--inverty/--no-inverty', default=True, help='invert y axis')
+@click.option('--invertx/--no-invertx', default=False, help='invert x axis')
+def main(
+    job_dir,
+    dest_dir,
+    overwrite,
+    dry_run,
+    copy,
+    micrographs,
+    patches,
+    sets,
+    classes,
+    swapxy,
+    inverty,
+    invertx,
+):
     """
     Copy and convert a cryosparc dir into a relion-ready dir.
 
-    JOB_DIR: a cryosparc job containing particles files.
+    \b
+    Parameters
+    ==========
+    JOB_DIR:
+        a cryosparc job containing particles files.
+    DEST_DIR:
+        the destination directory. [default: '.']
 
-    DEST_DIR: the destination directory. [default: '.']
+    WARNING! This script will use --swapxy and --inverty by default.
+    This is because *usually* this is the convention change between
+    cryosparc and relion. However, your mileage may vary, so you
+    are encouraged to check you data after conversion.
+
+    Note that if -p/-m are not passed, those columns are not
+    usable (due to the mrc extension and broken path).
     """
     log = ['=' * 80]
 
@@ -49,7 +72,7 @@ def main(job_dir, dest_dir, overwrite, dry_run, copy, micrographs, patches, reli
             continue
         if 'particles' not in name and 'split_' not in name:
             continue
-        if 'excluded' in name or 'remainder' in name:
+        if any(s in name for s in ('excluded', 'remainder', 'rejected', 'uncategorized')):
             continue
         if 'passthrough' in str(f):
             passthroughs.append(f)
@@ -118,8 +141,9 @@ def main(job_dir, dest_dir, overwrite, dry_run, copy, micrographs, patches, reli
     click.secho('Converting to star format...')
     for f, p in zip(particles, passthrough_files):
         data = np.load(f)
-        df_part = pyem.metadata.parse_cryosparc_2_cs(data, passthroughs=p,
-                                                     minphic=0, boxsize=None, swapxy=False)
+        df_part = pyem.metadata.parse_cryosparc_2_cs(
+            data, passthroughs=p,
+            minphic=0, boxsize=None, swapxy=swapxy, invertx=invertx, inverty=inverty)
         df = df.append(df_part, ignore_index=True)
 
     if classes is not None:
@@ -161,17 +185,16 @@ def main(job_dir, dest_dir, overwrite, dry_run, copy, micrographs, patches, reli
         basename = Path(path).name
         return str(new_parent / basename) + 's'
 
-    relion_base_dir = Path(relion_base_dir or dest_dir)
+    dest_dir = dest_dir.absolute()  # needed because relion thinks anything is relative to its "base" directory
     if micrographs:
         try:
             paths = np.unique(df['rlnMicrographName'].to_numpy())
         except KeyError:
             raise click.UsageError('could not find micrograph paths in the data.')
         # change them to the copied/symlinked version
-        target_dir = relion_base_dir / 'micrographs'
+        target_dir = dest_dir / 'micrographs'
         df['rlnMicrographName'] = df['rlnMicrographName'].apply(fix_path, new_parent=target_dir)
 
-        df['rlnMicrographName'] = '/micrographs/' + df['rlnMicrographName'].str.split('/').str.get(-1) + 's'
         copy_images(paths, dest_micrographs, copy)
     if patches:
         for col in ('rlnImageName', 'ucsfImagePath'):
@@ -182,7 +205,7 @@ def main(job_dir, dest_dir, overwrite, dry_run, copy, micrographs, patches, reli
             raise click.UsageError('could not find patch paths in the data. Were the particles ever extracted?')
         paths = np.unique(df[col_name].to_numpy())
         # change them to the copied/symlinked version
-        target_dir = relion_base_dir / 'patches'
+        target_dir = dest_dir / 'patches'
         df[col_name] = df[col_name].apply(fix_path, new_parent=target_dir)
         copy_images(paths, dest_patches, copy)
 
@@ -197,7 +220,3 @@ def main(job_dir, dest_dir, overwrite, dry_run, copy, micrographs, patches, reli
         f.write(f'{header}\n{command}\n{log}\n')
 
     click.secho('Done!')
-
-
-if __name__ == '__main__':
-    main()
